import React, { useState, useEffect, useCallback } from 'react'

import Alert from './components/Alert'

function useOrientation(){
  const [orientation, setOrientation] = useState("landscape")
  const mql = window.matchMedia("(orientation:landscape)")
  console.log(mql)
  
  const handler = useCallback(
    () => {

      if(mql.matches){
        setOrientation("landscape")
      }else{
        setOrientation("portrait")
      }
    },
    [setOrientation, mql],
  )

  window.addEventListener("orientationchange", handler)
  useEffect(() => {
    handler()
  }, [handler])

  return orientation
}

function useResolution(){
  const [resolution, setResolution] = useState({width: window.innerWidth, height: window.innerHeight})

  const handler = useCallback(
    () => {
      setResolution({width: window.innerWidth, height: window.innerHeight})
    },
    [setResolution],
  )

  window.addEventListener("resize", handler)
  useEffect(() => {
    handler()
  }, [handler])

  return resolution
}

function useDefineContent(App){
  const orientation = useOrientation()
  const resolution = useResolution()

  if(orientation === "portrait" || (orientation==="landscape" && (resolution.width>=600 && resolution.height >= 400)))
      return <App/>
    else
      return <Alert/>
}

export default useDefineContent