import React, { Component } from 'react'
import styled from 'styled-components'
import {Link} from 'react-router-dom'
import {breakpoints} from '../styled/variables'
import {colors} from '../styled/variables'
import {queries} from '../styled/variables'
import {utils} from '../styled/variables'
import ButtonHome from '../components/ButtonHome'
//material-ui
import Container from '@material-ui/core/Container'
import Typography from '@material-ui/core/Typography'
import Grid from '@material-ui/core/Grid'

//assets
import deficientes from '../assets/images/deficientes-logo.png'
import { ReactComponent as BtnVoltar } from  '../assets/images/voltar.svg'
import { ReactComponent as BtnAvancar } from '../assets/images/avancar.svg'

const FundoAzul = styled.div`
    width: 100%;
    height: 100%;
    background-size: 100% 100% !important;
    background-color: ${colors.tertiary};
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
`
const ContainerBranco = styled(Container)`
  background-color: #FFF;
  width: 95% !important;
  height: 95%;
  border-radius: 2%;
  .grid{
    height: 100%;
  }
  .titulo{
    color: ${colors.primary};
    text-align: justify; 
    height: 20%;
    display: flex;
    align-items: center;
    justify-content: center;
    width: 49%;
    text-align: center;
  }

  .conteudo{
    text-align: left;
    height: 70%;
    overflow: auto;
    width: 100%;
    ${queries.minWidth(breakpoints.md)}{
      width: 85%;
    }

    ${utils.hyphens()}
  }
  .divImg{
    max-width: 38%;
    @media(max-width: 576px){
      max-width: 100%;
      display:flex;
      align-items: center;
    }
  }
  .divText{
    min-width: 62%
  }
  .gridText{
    margin-top: 2%
  }
  .destaque{
    color: ${colors.primary};
  }

  .footer{
    height: 10%;
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: center;
    ${queries.minWidth(breakpoints.md)}{
      width: 90%;
    }
  }

  #logo-deficientes{
    width: 100%;
  }


  .navegacao{
    ${queries.minWidth(breakpoints.md)}{
      transform: scale(1.3);
    }
    svg{
      width: 50px;
      height: 40px;
      g{
        fill: ${colors.primary};
      }
    }

    .botao-desativado{
      g{
        fill: lightgray;
      }
    }
  }
  .grid{
    align-items:center
  }
`

export default class pages extends Component {

  render() {

    let title = `Convenção Internacional sobre os Direitos das Pessoas com Deficiência`
    let textOne = [`Considerando a necessidade de fortalecer o compromisso do Estado brasileiro com o reconhecimento dos direitos das pessoas com deficiência, garantindo a elas condições de vida com dignidade, autonomia e igualdade de oportunidades, o Brasil ratificou em 2008 a`,<span className="destaque"> Convenção Internacional sobre os Direitos das Pessoas com Deficiência</span>,`, adotada pela ONU, bem como seu Protocolo Facultativo.`]

    let textTwo = [`Essa medida conferiu poder constitucional à convenção e contribuiu para a ampliação de investimentos e elaboração de políticas intersetoriais. Isso possibilitou a construção de políticas públicas, visando à garantia, promoção da autonomia, igualdade de oportunidades e reafirmação dos direitos humanos, a partir do reconhecimento da deficiência como`,<span className="destaque"> uma característica da condição humana, e não uma limitação.</span>]

    return <FundoAzul>
              <ContainerBranco>
                <Grid container className="grid" direction="column" justify="center" alignItems="center">
                  {/* titulo */}
                  <Grid item className="titulo w-100">
                    <Typography variant="h5">
                      {title}
                    </Typography>
                  </Grid>
                  {/* conteudo */}
                  <Grid item className="conteudo">
                    <Grid container direction="column" justify="center" alignItems="center">
                      <Grid item>
                        <Typography>
                          {textOne}
                        </Typography>
                      </Grid>
                      <Grid item>
                        <Grid container className="grid gridText">
                          
                          <Grid item sm={6} className="divText">
                            <Typography>
                              {textTwo}
                            </Typography>
                          </Grid>
                          <Grid item sm={6} className="divImg">
                            <img id="logo-deficientes" src={deficientes} alt="..." />
                          </Grid>
                        </Grid>
                      </Grid>
                    </Grid>
                  </Grid>
                  {/* footer */}
                  <Grid item className="footer">
                    <Grid container className="w-100">
                        <Grid container className="w-100" direction="row" justify="space-between">
                          <ButtonHome/>
                          <div className="navegacao">
                            <Link>
                              <BtnVoltar className="botao-desativado"/>
                            </Link>
                            <Link to="/convencao-2">
                              <BtnAvancar className="avancar"/>
                            </Link>
                          </div>
                        </Grid>
                    </Grid>
                  </Grid>
                </Grid>
              </ContainerBranco>
           </FundoAzul>
  }
}
