import React, { Component } from 'react'
import styled from 'styled-components'
import {Link} from 'react-router-dom'
import {breakpoints} from '../styled/variables'
import {colors} from '../styled/variables'
import {queries} from '../styled/variables'
import {utils} from '../styled/variables'
import ButtonHome from '../components/ButtonHome'
//material-ui
import Container from '@material-ui/core/Container'
import Typography from '@material-ui/core/Typography'
import Grid from '@material-ui/core/Grid'
//assets
import cadeirante from '../assets/images/cadeirante.png'
import { ReactComponent as BtnVoltar } from  '../assets/images/voltar.svg'
import { ReactComponent as BtnAvancar } from '../assets/images/avancar.svg'

const FundoAzul = styled.div`
    width: 100%;
    height: 100%;
    background-size: 100% 100% !important;
    background-color: ${colors.tertiary};
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
`
const ContainerBranco = styled(Container)`
  background-color: #FFF;
  width: 95% !important;
  height: 95%;
  border-radius: 2%;
  .grid{
    height: 100%;
  }
  .titulo{
    color: ${colors.primary};
    text-align: center; 
    height: 20%;
    width: 49%;
    display: flex;
    align-items: center;
    justify-content: center;
  }

  .destaque{
    color: ${colors.primary};
  }

  .conteudo{
    text-align: left;
    height: 70%;
    overflow: auto;
    width: 100%;

    .imgDiv{
      width: 43%
    }
    img{
      width: 90%;
    }

    ${queries.minWidth(breakpoints.md)}{
      width: 85%;
    }

    ${utils.hyphens()}
  }

  .footer{
    height: 10%;
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: center;
    ${queries.minWidth(breakpoints.md)}{
      width: 90%;
    }
  }

  #logo-deficientes{
    width: 100%;
  }

  .button-home{
    ${queries.minWidth(breakpoints.md)}{
      transform: scale(1.3);
    }
    width: 45px;
    height: 45px;
    background-color: ${colors.primary};
    border-radius: 50%;
    color: #FFF;
    display: flex;
    margin-bottom: 2%;
    align-items: center;
    justify-content: center;
    text-decoration: none;

    &:hover{
      color: ${colors.primary};
      background-color: #FFF;
      border: 3px solid ${colors.primary};
    }
    .MuiButton-label{
      width: 50%;
      padding: 2%;
      vertical-align: center;
    }
  }

  .navegacao{
    ${queries.minWidth(breakpoints.md)}{
      transform: scale(1.3);
    }
    svg{
      width: 50px;
      height: 40px;
      g{
        fill: ${colors.primary};
      }
    }

    .botao-desativado{
      g{
        fill: lightgray;
      }
    }
  }
`

export default class pages extends Component {

  render() {

    let title = `Convenção Internacional sobre os Direitos das Pessoas com Deficiência`
    
    return <FundoAzul>
              <ContainerBranco>
                <Grid container className="grid" direction="column" justify="center" alignItems="center">
                  {/* titulo */}
                  <Grid item className="titulo w-100">
                    <Typography variant="h5">
                      {title}
                    </Typography>
                  </Grid>
                  {/* conteudo */}
                  <Grid item className="conteudo">
                    <Grid container direction="row" justify="center" alignItems="center">
                      <Grid item sm={6} className="imgDiv">
                        <img src={cadeirante} alt="..." />
                      </Grid>
                      <Grid item sm={6}>
                        <Typography>
                        Com isso, toda e qualquer ação de Política Pública e Social no Brasil para pessoas com deficiência a reconhecem como um conceito em evolução, no qual ela resulta da <span className="destaque">interação entre pessoas com deficiência e barreiras existentes no ambiente</span>, que as impedem, de maneira significativa, de participar na vida em sociedade e usufruir dos mesmos direitos que as outras pessoas. 
                        </Typography>
                      </Grid>
                    </Grid>
                  </Grid>
                  {/* footer */}
                  <Grid item className="footer">
                    <Grid container className="w-100">
                        <Grid container className="w-100" direction="row" justify="space-between">
                          <ButtonHome/>
                          <div className="navegacao">
                            <Link to="/convencao-1">
                              <BtnVoltar/>
                            </Link>
                            <Link>
                              <BtnAvancar className="botao-desativado"/>
                            </Link>
                          </div>
                        </Grid>
                    </Grid>
                  </Grid>
                </Grid>
              </ContainerBranco>
           </FundoAzul>
  }
}
