import React, { Component } from 'react'
import styled from 'styled-components'
import {Link} from 'react-router-dom'
import {breakpoints} from '../styled/variables'
import {colors} from '../styled/variables'
import {queries} from '../styled/variables'
import {utils} from '../styled/variables'
import ButtonHome from '../components/ButtonHome'
//material-ui
import Container from '@material-ui/core/Container'
import Typography from '@material-ui/core/Typography'
import Grid from '@material-ui/core/Grid'
//assets
import { ReactComponent as BtnVoltar } from  '../assets/images/voltar.svg'
import { ReactComponent as BtnAvancar } from '../assets/images/avancar.svg'

const FundoAzul = styled.div`
    width: 100%;
    height: 100%;
    background-size: 100% 100% !important;
    background-color: ${colors.tertiary};
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;

  .modal-header{
    border-bottom: 0;
  }
  .modal-body{
    text-decoration: justify;
    ${utils.hyphens()}
  }
`
const ContainerBranco = styled(Container)`
  background-color: #FFF;
  width: 95% !important;
  height: 95%;
  border-radius: 2%;
  .grid{
    height: 100%;
  }
  .titulo{
    color: ${colors.primary};
    text-align: justify; 
    height: 25%;

    display: flex;
    align-items: center;
    justify-content: center;
    width: 49%;
    text-align: center;

    ${queries.minWidth(breakpoints.sm)}{
      height: 20%;
    }
  }

  .destaque{
    color: ${colors.primary};
  }

  .conteudo{
    text-align: left;
    height: 61%;
    ${queries.minWidth(breakpoints.sm)}{
      height: 70%;
    }
    overflow: auto;
    width: 100%;

    img{
      width: 100%;
    }

    ${queries.minWidth(breakpoints.md)}{
      width: 85%;
    }

    ${utils.hyphens()}
  }

  .footer{
    height: 10%;
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: center;
    ${queries.minWidth(breakpoints.md)}{
      width: 90%;
    }
  }

  #logo-deficientes{
    width: 100%;
  }

  .button-home{
    ${queries.minWidth(breakpoints.md)}{
      transform: scale(1.3);
    }
    width: 45px;
    height: 45px;
    background-color: ${colors.primary};
    border-radius: 50%;
    color: #FFF;
    margin-bottom: 2%;
    display: flex;
    align-items: center;
    justify-content: center;
    text-decoration: none;

    &:hover{
      color: ${colors.primary};
      background-color: #FFF;
      border: 3px solid ${colors.primary};
    }
    .MuiButton-label{
      width: 50%;
      padding: 2%;
      vertical-align: center;
    }
  }

  .navegacao{
    ${queries.minWidth(breakpoints.md)}{
      transform: scale(1.3);
    }
    svg{
      width: 50px;
      height: 40px;
      g{
        fill: ${colors.primary};
      }
    }

    .botao-desativado{
      g{
        fill: lightgray;
      }
    }
  }

  .MuiButton-containedPrimary{
    width: fit-content;
    align-self: center;
    cursor: pointer;
    background-color: ${colors.primary};
    &:hover{
      background-color: ${colors.secondary} !important;
    }
    &:focus{
      background-color: ${colors.primary} !important;
    }

    a{
      color: #FFF;
      text-decoration: none !important;
    }
  }

  .board-color-primary{
    background-color: #b4e6fa;
    text-align: justify;
    border-radius: 10px;
    padding: 1.5% 4%;

    ${utils.hyphens()}
  }
`

export default class pages extends Component {

  render() {

    
    return <FundoAzul>
              <ContainerBranco>
                <Grid container className="grid" direction="column" justify="center" alignItems="center">
                  {/* titulo */}
                  <Grid item className="titulo w-100">
                    <Typography variant="h5">
                      {/* title */}
                      Lei Brasileira de Inclusão da Pessoa com Deficiência 
                    </Typography>
                  </Grid>
                  {/* conteudo */}
                  <Grid item className="conteudo">
                    <Grid container className="w-100" direction="column" justify="center">
                      <p>
                        <Typography>
                          Por meio da Lei nº 13.146, de 06 de julho de 2015, o Governo Brasileiro instituiu a <span className="destaque">Lei Brasileira de Inclusão da Pessoa com Deficiência (Estatuto da Pessoa com Deficiência).</span>
                        </Typography>
                      </p>
                      <br/>
                      <div className="board-color-primary">
                        <Typography>
                        Essa lei busca assegurar e promover, em condições de igualdade, o exercício dos direitos e das liberdades constitucionais e fundamentais pela pessoa com deficiência, objetivando a sua inclusão social e cidadã.
                        </Typography>
                      </div>
                      <br/>
                      <Typography>
                      A referida lei, instituída a partir da Convenção Internacional dos Direitos das Pessoas com Deficiência, consolidou a mudança quanto ao que se entende por pessoa com deficiência e deficiência. Como no Brasil havia uma série de legislações anteriores à Convenção, que usavam termos ou mesmo pensavam a deficiência ainda como uma condição estática e biológica da pessoa, por exemplo, a Lei Brasileira de Inclusão unifica o conceito, atrelando-o ao texto da Convenção ratificada pelo Brasil, em 2008.
                      </Typography>
                    </Grid>
                  </Grid>
                  {/* footer */}
                  <Grid item className="footer">
                    <Grid container className="w-100">
                        <Grid container className="w-100" direction="row" justify="space-between">
                          <ButtonHome/>
                          <div className="navegacao">
                            <Link >
                              <BtnVoltar className="botao-desativado"/>
                            </Link>
                            <Link to="/lei-2">
                              <BtnAvancar/>
                            </Link>
                          </div>
                        </Grid>
                    </Grid>
                  </Grid>
                </Grid>
              </ContainerBranco>
           </FundoAzul>
  }
}
