import React, { Component } from 'react'
import styled from 'styled-components'
import {breakpoints} from '../styled/variables'
import {colors} from '../styled/variables'
import {queries} from '../styled/variables'
import {utils} from '../styled/variables'
import Carousel from '../components/Carousel'
import ButtonCapa from '../components/ButtonCapa'
import {Link} from 'react-router-dom'
//material-ui
import Container from '@material-ui/core/Container'
import Typography from '@material-ui/core/Typography'
import Grid from '@material-ui/core/Grid'
import Button from '@material-ui/core/Button'
//assets
import personagem from '../assets/images/personagem.png'
import btn1 from '../assets/images/button-menu-1.png'
import btn2 from '../assets/images/button-menu-2.png'
import btn3 from '../assets/images/button-menu-3.png'


const FundoAzul = styled.div`
    width: 100%;
    height: 100%;
    background-size: 100% 100% !important;
    background-color: ${colors.tertiary};
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
`
const ContainerBranco = styled(Container)`
  background-color: #FFF;
  width: 95% !important;
  height: 95%;
  border-radius: 2%;

  .grid-size{
    width: 100%;
    height: 100%;
  }

  .grid-item-height{
    height: 30.3333% !important;
    
    &:first-child{
      height: 34.3333% !important;

      ${queries.minWidth(breakpoints.sm)}{
        background-color: #CBDBE9;
      }
    }
  }

  #texto-instrucional{
    text-align: justify;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    height: 20% !important;
  }

  .w-100{
    width: 100%;
  }
  

  .MuiButton-containedPrimary{
    cursor: pointer;
    text-align: center;
    border-radius: 2rem;
    background-color: ${colors.primary};
    &:hover{  
      text-align: center;
      background-color: ${colors.secondary};
      border: 3px solid ${colors.primary};
    }
    &:focus{
      background-color: ${colors.primary} !important;
    }

    a{
      color: #FFF;
      text-decoration: none !important;
    }

    .MuiTypography-body1{
      letter-spacing:  0.02857em;
      text-transform: none;
    }
  }


  #item-menu-3{
    height: 132px;
    ${queries.minWidth(breakpoints.sm)}{
      height: 100%;
    }
  }

  .button-height{
    ${queries.minWidth(breakpoints.md)}{
      min-height: 132px;
    } 
  }

  .btn{
    background-color: ${colors.primary};
    border-radius: 10px;
    box-shadow: 5px 5px 10px black;
    font-size: 1rem;
    ${queries.minWidth(breakpoints.md)}{
      font-size: 1.4rem;
    } 
    a{
      color: #FFF;
      text-decoration: none;
      font-size: 1.1rem;
    }


    &:hover{
      background-color: ${colors.primary};
    }
  }

  .button-bar{
    transform: scale(0.7);
  }

  .button-height-mobile{
    ${queries.minHeight("600px")}{
      padding: 0 12%;
    }
    ${queries.minHeight("700px")}{
      height: 8rem;
    }
  }

  .show-only-mobile{
    display: flex;
    ${queries.minWidth(breakpoints.sm)}{
      display:none;
    }
  }

  .show-only-tablet-desktop{
    display: none;
    
    ${queries.minWidth(breakpoints.sm)}{
      display:flex;
      width: 100%;
    }
  }

  #personagem{
    width: 25%;
    ${queries.minWidth(breakpoints.sm)}{
      max-width: 170px;
      max-height: 203px;
      margin-left: 5%;
    }
  }

  .text-color-primary{
    color: ${colors.primary};
  }
`

const BalaoCinza = styled.div`
  width: 100%;
  height: auto;
  background: #ffffff;
  border-radius: 2%;
  border: 3px solid #AFACAC;
  
  padding: 5% 3%;
  box-sizing: border-box;
  text-align: left;

  ${queries.minWidth(breakpoints.sm)}{
    position: relative;
    background: #ffffff;
    border-radius: 1.2em;
    width: 65%;
    max-width: 30rem;
    max-height: 150px;

    &:after{
      content: '';
      position: absolute;
      right: 0;
      top: 50%;
      width: 0;
      height: 0;
      border: 42px solid transparent;
      border-left-color:#ffffff;
      border-right: 0;
      border-top: 0;
      margin-top: -28.5px;
      margin-right: -42px;
    }

    &:before{
      content: '';
      position: absolute;
      right: 0;
      top: 50%;
      width: 0;
      height: 0;
      border: 46px solid transparent;
      border-left-color: #AFACAC;
      border-right: 0;
      border-top: 0;
      margin-top: -30.5px;
      margin-right: -48px;
    }
  }

  ${queries.minWidth(breakpoints.md)}{
    max-width: 28rem;
    max-height: 150px;
    margin-left: 2rem;
  }
  
  ${utils.hyphens()}
`

export default class pages extends Component {
  


  render() {

    let textBalaoCinza = `Neste material, queremos que você conheça os principais marcos internacionais e nacionais dos direitos das pessoas com deficiência.`
    let textInstrucao = [`Clique em cada um dos botões para iniciar a leitura`]

    let textButtonOne = `Convenção Internacional sobre os Direitos das Pessoas com Deficiência`
    let textButtonTwo = `Plano Nacional dos Direitos da Pessoa com Deficiência - Plano Viver sem Limite`
    let textButtonThree = `Lei Brasileira de Inclusão da Pessoa com Deficiência`

    return <FundoAzul>
              <ContainerBranco>
                <Grid className="grid-size position-relative w-100 h-100" container direction="column" justify="center" alignItems="center">
                  <Grid item className="grid-item-height d-flex align-items-center justify-content-center">
                    <BalaoCinza>
                      <Typography className="personagem">
                        {textBalaoCinza}
                      </Typography>
                    </BalaoCinza>
                    <img id="personagem" className="show-only-tablet-desktop" src={personagem} alt="..."/>
                  </Grid>
                  <Grid item id="texto-instrucional" className="grid-item-height text-color-primary">
                      <Typography className="menubtn">
                        {textInstrucao}
                      </Typography>
                  </Grid>
                  <Grid item className="grid-item-height w-100">
                      <Carousel className="show-only-mobile">
                        <div className="w-100 animated fadeIn">
                          <div className="w-100 h-100 d-flex align-items-center justify-content-center p-3">
                            <button className="btn btn-primary">
                              <Link to="/convencao-1">
                                {textButtonOne}
                              </Link>
                            </button>
                          </div>
                        </div>
                        <div className="w-100 animated fadeIn">
                          <div className="w-100 h-100 d-flex align-items-center justify-content-center p-3">
                            <button className="btn btn-primary">
                              <Link to="/plano-1">
                                {textButtonTwo}
                              </Link>
                            </button>
                          </div>
                        </div>
                        <div className="w-100 animated fadeIn">
                          <div className="w-100 h-100 d-flex align-items-center justify-content-center p-3">
                            <button className="btn btn-primary h-100">
                              <Link to="/lei-1">
                                {textButtonThree}
                              </Link>
                            </button>
                          </div>
                        </div>
                      </Carousel>
                      <div className="show-only-tablet-desktop button-bar">
                          <Grid container direction="row" spacing={2}>
                            <Grid item sm={4}>
                              <Link to="/convencao-1">
                                <img className="img-fluid" src={btn1} alt="..."/>
                              </Link>
                            </Grid>
                            <Grid item sm={4}>
                              <Link to="/plano-1">
                              <img className="img-fluid" src={btn2} alt="..."/>
                              </Link>
                            </Grid>
                            <Grid item sm={4}>
                              <Link to="/lei-1">
                                <img className="img-fluid" src={btn3} alt="..."/>
                              </Link>
                            </Grid>
                          </Grid>
                      </div>
                  </Grid>
                  <ButtonCapa/>
                </Grid>
              </ContainerBranco>
           </FundoAzul>
  }
}
